@@ -19,41 +19,37 @@
 #ifndef HTMLEXPRESSIONWRITER_H
 #define HTMLEXPRESSIONWRITER_H
 
-#include "abstractexpressionvisitor.h"
+#include "expressionwriter.h"
 
 namespace Analitza
 {
 
 /**
- * \class HtmlExpressionWriter
- * 
- * \ingroup AnalitzaModule
+ *	This class represents the string expression writer.
  *
- * \brief This class represents the string expression writer.
+ *	@author Aleix Pol <aleixpol@kde.org>  
  */
 
-class HtmlExpressionWriter : public AbstractExpressionVisitor
+class HtmlExpressionWriter : public ExpressionWriter
 {
 	public:
 		HtmlExpressionWriter(const Object* o);
 		
-		virtual QVariant visit(const Ci* var);
-		virtual QVariant visit(const Cn* var);
-		virtual QVariant visit(const Container* var);
-		virtual QVariant visit(const Operator* var);
-		virtual QVariant visit(const Vector* var);
-		virtual QVariant visit(const List* l);
-		virtual QVariant visit(const Apply* a);
-		virtual QVariant visit(const CustomObject* c);
-		virtual QVariant visit(const Matrix* c);
-		virtual QVariant visit(const MatrixRow* c);
+		virtual QString accept(const Ci* var);
+		virtual QString accept(const Cn* var);
+		virtual QString accept(const Container* var);
+		virtual QString accept(const Operator* var);
+		virtual QString accept(const Vector* var);
+		virtual QString accept(const List* l);
+		virtual QString accept(const Apply* a);
+		virtual QString accept(const CustomObject* c);
 		
-		QVariant result() const { return m_result; }
+		QString result() const { return m_result; }
 		
 	private:
 		template <class T>
-			static QStringList allValues(T it, const T& itEnd, AbstractExpressionVisitor* writer);
-		QVariant m_result;
+			static QStringList allValues(T it, const T& itEnd, ExpressionWriter* writer);
+		QString m_result;
 };
 
 }
