@@ -152,7 +152,7 @@ void AnalitzaTest::testTrivialEvaluate_data()
 	QTest::newRow("undefined function call") << "f(2)" << "f(2)";
 	QTest::newRow("--simplification") << "-(-x)" << "x";
 	QTest::newRow("unneeded --simplification") << "-(x-x)" << "0";
-	QTest::newRow("minus order") << "1-x" << "1-x";
+	QTest::newRow("minus order") << "1-x" << "-x--1";
 	QTest::newRow("minus order2") << "x-1" << "x-1";
 	QTest::newRow("after simp(minus) --simplification") << "-(x-x-x)" << "x";
 	QTest::newRow("and") << "and(6>5, 4<5)" << "true";
@@ -570,9 +570,19 @@ void AnalitzaTest::testSimplify_data()
 	
 	QTest::newRow("identity") << "1*x" << "x";
 	QTest::newRow("minus") << "x-x-x" << "-x";
+	QTest::newRow("minus1") << "x-1" << "x-1";
+	QTest::newRow("minus2") << "x-2*x" << "-x";
 	QTest::newRow("compensation") << "-(4*x)+3*x" << "-x";
+	QTest::newRow("compensation1") << "(-(4*x))+3*x" << "-x";
+	QTest::newRow("compensation2") << "((-4)*x)+3*x" << "-x";
 	QTest::newRow("compensation*") << "-(x^4)*x^3" << "-x^7";
 	QTest::newRow("powers") << "3**x*5**x" << "3^x*5^x";
+	QTest::newRow("poli1") << "x-1+2" << "x+1";
+	QTest::newRow("poli2") << "(x+y)-z" << "x--y-z";
+	QTest::newRow("poli3") << "2-13-(x+1)" << "-x-12";
+	QTest::newRow("poli4") << "-x-1-2-4" << "-x-7";
+	QTest::newRow("poli4.0") << "-x-y-z" << "-x-y-z";
+	QTest::newRow("poli4.1") << "minus(-x, 1, 2, 4)" << "-x-7";
 // 	QTest::newRow("powerscomb") << "3**x*3**x" << "9^x";
 	QTest::newRow("no var") << "2+2" << "4";
 	QTest::newRow("simple") << "x+x" << "2*x";
@@ -599,6 +609,20 @@ void AnalitzaTest::testSimplify_data()
 	QTest::newRow("mono") << "2*x*y+3*x*y" << "5*x*y";
 	QTest::newRow("mono1") << "2*y+y" << "3*y";
 	QTest::newRow("mono2") << "-y+1" << "-y+1";
+	
+	//equations
+	QTest::newRow("eqminus") << "x-3=0" << "x=3";
+	QTest::newRow("eqplus") << "x+3=0" << "x=-3";
+	QTest::newRow("eqtimes") << "3x=0" << "x=0";
+	QTest::newRow("eqtimes1") << "(x-3)*(x-2)=0" << "or(x=3, x=2)";
+	QTest::newRow("eqdiv") << "x/2=0" << "x=0";
+	QTest::newRow("eqdiv1") << "(x-1)/2=0" << "x=1";
+	QTest::newRow("eqdiv2") << "(x*(x-1))/x=0" << "x=1";
+	QTest::newRow("eqdiv3") << "(x*(x-1))/(x+3)=0" << "or(x=0, x=1)";
+	QTest::newRow("eqsin") << "sin(x)=0" << "x=0";
+	QTest::newRow("eqcos") << "cos(x)=1" << "x=0";
+    QTest::newRow("eqmin") << "x=3-2" << "x=1";
+	QTest::newRow("different") << "x+3=x+2" << "false";
 }
 
 void AnalitzaTest::testSimplify()
